@@ -32,9 +32,9 @@ __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
 import os
 # this will be filled by the setup
-PYMCA_DATA_DIR = r'C:\bld\pymca_1566832701444\_h_env\Lib\site-packages\PyMca5\PyMcaData'
+PYMCA_DATA_DIR = r'D:\bld\pymca_1570099900762\_h_env\Lib\site-packages\PyMca5\PyMcaData'
 # This is to be filled by the setup
-PYMCA_DOC_DIR = r'C:\bld\pymca_1566832701444\_h_env\Lib\site-packages\PyMca5\PyMcaData'
+PYMCA_DOC_DIR = r'D:\bld\pymca_1570099900762\_h_env\Lib\site-packages\PyMca5\PyMcaData'
 
 PYMCA_DATA_DIR_ENV = os.getenv("PYMCA_DATA_DIR")
 if PYMCA_DATA_DIR_ENV is not None:
@@ -73,7 +73,7 @@ if PYMCA_DOC_DIR_ENV is not None:
         raise IOError('%s directory set from environent not found' % \
                           PYMCA_DATA_DIR)
     else:
-        txt = "WARNING: Taking PYMCA_DOC_DIR from environement.\n"
+        txt = "WARNING: Taking PYMCA_DOC_DIR from environment.\n"
         txt += "Use it at your own risk."
         print(txt)
 
